<?php

namespace Annie\Campaigns\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Campaigns\Models\CampaignKindSupport;

class CampaignKindSupportPolicy
{

    /**
     * Determine if the given user can view the campaign_kind_support.
     *
     * @param UserPolicy $user
     * @param CampaignKindSupport $campaign_kind_support
     *
     * @return bool
     */
    public function view(UserPolicy $user, CampaignKindSupport $campaign_kind_support)
    {
        if ($user->canDo('campaigns.campaign_kind_support.view') && $user->isAdmin()) {
            return true;
        }

        return $campaign_kind_support->user_id == user_id() && $campaign_kind_support->user_type == user_type();
    }

    /**
     * Determine if the given user can create a campaign_kind_support.
     *
     * @param UserPolicy $user
     * @param CampaignKindSupport $campaign_kind_support
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('campaigns.campaign_kind_support.create');
    }

    /**
     * Determine if the given user can update the given campaign_kind_support.
     *
     * @param UserPolicy $user
     * @param CampaignKindSupport $campaign_kind_support
     *
     * @return bool
     */
    public function update(UserPolicy $user, CampaignKindSupport $campaign_kind_support)
    {
        if ($user->canDo('campaigns.campaign_kind_support.edit') && $user->isAdmin()) {
            return true;
        }

        return $campaign_kind_support->user_id == user_id() && $campaign_kind_support->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given campaign_kind_support.
     *
     * @param UserPolicy $user
     * @param CampaignKindSupport $campaign_kind_support
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CampaignKindSupport $campaign_kind_support)
    {
        return $campaign_kind_support->user_id == user_id() && $campaign_kind_support->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given campaign_kind_support.
     *
     * @param UserPolicy $user
     * @param CampaignKindSupport $campaign_kind_support
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CampaignKindSupport $campaign_kind_support)
    {
        if ($user->canDo('campaigns.campaign_kind_support.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given campaign_kind_support.
     *
     * @param UserPolicy $user
     * @param CampaignKindSupport $campaign_kind_support
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CampaignKindSupport $campaign_kind_support)
    {
        if ($user->canDo('campaigns.campaign_kind_support.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
