<?php

namespace Annie\Campaigns\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Campaigns\Models\CampaignVolunteer;

class CampaignVolunteerPolicy
{

    /**
     * Determine if the given user can view the campaign_volunteer.
     *
     * @param UserPolicy $user
     * @param CampaignVolunteer $campaign_volunteer
     *
     * @return bool
     */
    public function view(UserPolicy $user, CampaignVolunteer $campaign_volunteer)
    {
        if ($user->canDo('campaigns.campaign_volunteer.view') && $user->isAdmin()) {
            return true;
        }

        return $campaign_volunteer->user_id == user_id() && $campaign_volunteer->user_type == user_type();
    }

    /**
     * Determine if the given user can create a campaign_volunteer.
     *
     * @param UserPolicy $user
     * @param CampaignVolunteer $campaign_volunteer
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('campaigns.campaign_volunteer.create');
    }

    /**
     * Determine if the given user can update the given campaign_volunteer.
     *
     * @param UserPolicy $user
     * @param CampaignVolunteer $campaign_volunteer
     *
     * @return bool
     */
    public function update(UserPolicy $user, CampaignVolunteer $campaign_volunteer)
    {
        if ($user->canDo('campaigns.campaign_volunteer.edit') && $user->isAdmin()) {
            return true;
        }

        return $campaign_volunteer->user_id == user_id() && $campaign_volunteer->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given campaign_volunteer.
     *
     * @param UserPolicy $user
     * @param CampaignVolunteer $campaign_volunteer
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CampaignVolunteer $campaign_volunteer)
    {
        return $campaign_volunteer->user_id == user_id() && $campaign_volunteer->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given campaign_volunteer.
     *
     * @param UserPolicy $user
     * @param CampaignVolunteer $campaign_volunteer
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CampaignVolunteer $campaign_volunteer)
    {
        if ($user->canDo('campaigns.campaign_volunteer.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given campaign_volunteer.
     *
     * @param UserPolicy $user
     * @param CampaignVolunteer $campaign_volunteer
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CampaignVolunteer $campaign_volunteer)
    {
        if ($user->canDo('campaigns.campaign_volunteer.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
