<?php

namespace Annie\Campaigns\Providers;

use Illuminate\Support\ServiceProvider;

class CampaignsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'campaigns');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'campaigns');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerCampaigns();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerCampaigns()
    {
        $this->app->bind('campaigns', function($app) {
            return new Campaigns($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Campaigns', 'Lavalite\Campaigns\Facades\Campaigns');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('annie.campaigns', function ($app) {
            return $this->app->make('Annie\Campaigns\Campaigns');
        });

        // Bind Campaign to repository
        $this->app->bind(
            'Annie\Campaigns\Interfaces\CampaignRepositoryInterface',
            \Annie\Campaigns\Repositories\Eloquent\CampaignRepository::class
        );
        // Bind CampaignKindSupport to repository
        $this->app->bind(
            'Annie\Campaigns\Interfaces\CampaignKindSupportRepositoryInterface',
            \Annie\Campaigns\Repositories\Eloquent\CampaignKindSupportRepository::class
        );
        // Bind CampaignVolunteer to repository
        $this->app->bind(
            'Annie\Campaigns\Interfaces\CampaignVolunteerRepositoryInterface',
            \Annie\Campaigns\Repositories\Eloquent\CampaignVolunteerRepository::class
        );

        $this->app->register(\Annie\Campaigns\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Annie\Campaigns\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and campaigns's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/campaigns.php', 'campaigns'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeCampaigns::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['annie.campaigns'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('annie/campaigns.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/campaigns')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/campaigns')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
